# Installation

In order to install `distribute` you must have a recent version of `rustc` and `cargo`. 
Install instructions can be found [here](https://www.rust-lang.org/tools/install). 

Once you have it (and running `cargo` shows some output), you can install the project with 

```
cargo install --git https://github.com/fluid-Dynamics-Group/distribute --force
```

and you are good to go! If you run into any trouble installing, let Brooks know.

## Python api install

```
pip3 install distribute_compute_config
```
